==> ejc-sale-api-3.0.0-20220413.133935-31-sources.jar: com.ejianc.business.sale/salesorder/vo/WeighinginfoApiVO.java <==
package com.ejianc.business.sale.salesorder.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 无人值守称重信息
 * 
 * @author generator
 * 
 */
public class WeighinginfoApiVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String numberPlate; // 车牌号
    private Date weighingTime; // 称重时间
    private Long productiontaskId; // 生产任务单id
    private Long poundRoomId; // 磅房ID
    private Long cameraId; // 摄像头ID
    private Long weigherId; // 磅头ID
    private Integer weighingMethod; // 称重方式 0,一次称重  1,毛重  2,皮重 
    private Integer print; // 是否打印   
    private Integer sendOrReceive; // 收发类型 0,收货 1,发货  
    private Long firstTimeId; // 上次称重ID
    private Long orgId; // 所属组织id
    private BigDecimal weight; // 称重重量

    

    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Date getWeighingTime() {
        return weighingTime;
    }

    public void setWeighingTime(Date weighingTime) {
        this.weighingTime = weighingTime;
    }
    public Long getPoundRoomId() {
        return poundRoomId;
    }

    public void setPoundRoomId(Long poundRoomId) {
        this.poundRoomId = poundRoomId;
    }
    public Long getCameraId() {
        return cameraId;
    }

    public void setCameraId(Long cameraId) {
        this.cameraId = cameraId;
    }
    public Long getWeigherId() {
        return weigherId;
    }

    public void setWeigherId(Long weigherId) {
        this.weigherId = weigherId;
    }
    public Integer getWeighingMethod() {
        return weighingMethod;
    }

    public void setWeighingMethod(Integer weighingMethod) {
        this.weighingMethod = weighingMethod;
    }
    public Integer getPrint() {
        return print;
    }

    public void setPrint(Integer print) {
        this.print = print;
    }
    public Integer getSendOrReceive() {
        return sendOrReceive;
    }

    public void setSendOrReceive(Integer sendOrReceive) {
        this.sendOrReceive = sendOrReceive;
    }
    public Long getFirstTimeId() {
        return firstTimeId;
    }

    public void setFirstTimeId(Long firstTimeId) {
        this.firstTimeId = firstTimeId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public Long getProductiontaskId() {
        return productiontaskId;
    }

    public void setProductiontaskId(Long productiontaskId) {
        this.productiontaskId = productiontaskId;
    }

    public BigDecimal getWeight() {
        return weight;
    }

    public void setWeight(BigDecimal weight) {
        this.weight = weight;
    }
}

==> ejc-sale-api-3.0.0-20220517.114239-120-sources.jar: com.ejianc.business.sale/salesorder/vo/WeighinginfoApiVO.java <==
package com.ejianc.business.sale.salesorder.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 无人值守称重信息
 * 
 * @author generator
 * 
 */
public class WeighinginfoApiVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String numberPlate; // 车牌号
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date weighingTime; // 称重时间
    private Long productiontaskId; // 生产任务单id
    private Long poundRoomId; // 磅房ID
    private Long cameraId; // 摄像头ID
    private Long weigherId; // 磅头ID
    private Integer weighingMethod; // 称重方式 0,一次称重  1,毛重  2,皮重 
    private Integer print; // 是否打印   
    private Integer sendOrReceive; // 收发类型 0,收货 1,发货  
    private Long firstTimeId; // 上次称重ID
    private Long orgId; // 所属组织id
    private BigDecimal weight; // 称重重量

    

    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Date getWeighingTime() {
        return weighingTime;
    }

    public void setWeighingTime(Date weighingTime) {
        this.weighingTime = weighingTime;
    }
    public Long getPoundRoomId() {
        return poundRoomId;
    }

    public void setPoundRoomId(Long poundRoomId) {
        this.poundRoomId = poundRoomId;
    }
    public Long getCameraId() {
        return cameraId;
    }

    public void setCameraId(Long cameraId) {
        this.cameraId = cameraId;
    }
    public Long getWeigherId() {
        return weigherId;
    }

    public void setWeigherId(Long weigherId) {
        this.weigherId = weigherId;
    }
    public Integer getWeighingMethod() {
        return weighingMethod;
    }

    public void setWeighingMethod(Integer weighingMethod) {
        this.weighingMethod = weighingMethod;
    }
    public Integer getPrint() {
        return print;
    }

    public void setPrint(Integer print) {
        this.print = print;
    }
    public Integer getSendOrReceive() {
        return sendOrReceive;
    }

    public void setSendOrReceive(Integer sendOrReceive) {
        this.sendOrReceive = sendOrReceive;
    }
    public Long getFirstTimeId() {
        return firstTimeId;
    }

    public void setFirstTimeId(Long firstTimeId) {
        this.firstTimeId = firstTimeId;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public Long getProductiontaskId() {
        return productiontaskId;
    }

    public void setProductiontaskId(Long productiontaskId) {
        this.productiontaskId = productiontaskId;
    }

    public BigDecimal getWeight() {
        return weight;
    }

    public void setWeight(BigDecimal weight) {
        this.weight = weight;
    }
}
